

class TakerBuySellVol:

    def __init__(self):
        self.pair = ""
        self.contractType = ""
        self.takerBuyVol = 0.0
        self.takerSellVol = 0.0
        self.takerBuyVolValue = 0.0
        self.takerSellVolValue = 0.0
        self.timestamp = 0
    
    @staticmethod
    def json_parse(json_data):
        result = TakerBuySellVol()
        result.pair = json_data.get_string("pair")
        result.contractType = json_data.get_string("contractType")
        result.takerBuyVol = json_data.get_float("takerBuyVol")
        result.takerSellVol = json_data.get_float("takerSellVol")
        result.takerBuyVolValue = json_data.get_float("takerBuyVolValue")
        result.takerSellVolValue = json_data.get_float("takerSellVolValue")
        result.timestamp = json_data.get_int("timestamp")

        return result





class Basis:

    def __init__(self):
        self.pair = ""
        self.contractType = ""
        self.futuresPrice = 0.0
        self.indexPrice = 0.0
        self.basis = 0.0
        self.basisRate = 0.0
        self.timestamp = 0
    
    @staticmethod
    def json_parse(json_data):
        result = Basis()
        result.pair = json_data.get_string("pair")
        result.contractType = json_data.get_string("contractType")
        result.futuresPrice = json_data.get_float("futuresPrice")
        result.indexPrice = json_data.get_float("indexPrice")
        result.basis = json_data.get_float("basis")
        result.basisRate = json_data.get_float("basisRate")
        result.timestamp = json_data.get_int("timestamp")

        return result



class MarkPriceEvent:

    def __init__(self):
        self.eventType = ""
        self.eventTime = 0
        self.symbol = ""
        self.markPrice = 0.0
        self.estSettlmentPrice = 0.0

    @staticmethod
    def json_parse(json_data):
        result = MarkPriceEvent()
        result.eventType = json_data.get_string("e")
        result.eventTime = json_data.get_int("E")
        result.symbol = json_data.get_string("s")
        result.markPrice = json_data.get_float("p")
        result.estSettlmentPrice = json_data.get_float("P")
        return result



class Candlestick:

    def __init__(self):
        self.openTime = 0
        self.open = 0.0
        self.high = 0.0
        self.low = 0.0
        self.close = 0.0
        self.volume = 0.0
        self.closeTime = 0
        self.baseVolume = 0.0
        self.numTrades = 0
        self.takerBuyQuoteAssetVolume = 0.0
        self.takerBuyBaseAssetVolume = 0.0
        self.ignore = 0.0

    @staticmethod
    def json_parse(json_data):
        result = Candlestick()
        val = json_data.convert_2_list()
        result.openTime = val[0]
        result.open = val[1]
        result.high = val[2]
        result.low = val[3]
        result.close = val[4]
        result.volume = val[5]
        result.closeTime = val[6]
        result.baseVolume = val[7]
        result.numTrades = val[8]
        result.takerBuyQuoteAssetVolume = val[9]
        result.takerBuyBaseAssetVolume = val[10]
        result.ignore = val[11]
  
        return result




class LongShortPositions:

    def __init__(self):
        self.pair = ""
        self.longShortRatio = 0.0  #  long/short account num ratio of top traders
        self.longPosition = 0.0  # long account num ratio of top traders
        self.shortPosition = 0.0  # short account num ratio of top traders 
        self.timestamp = 0
    
    @staticmethod
    def json_parse(json_data):
        result = LongShortPositions()
        result.pair = json_data.get_string("pair")
        result.longShortRatio = json_data.get_float("longShortRatio")
        result.longPosition = json_data.get_float("longPosition")
        result.shortPosition = json_data.get_float("shortPosition")
        result.timestamp = json_data.get_int("timestamp")

        return result



class IndexPriceEvent:

    def __init__(self):
        self.eventType = ""
        self.eventTime = 0
        self.pair = ""
        self.indexPrice = 0.0

    @staticmethod
    def json_parse(json_data):
        result = IndexPriceEvent()
        result.eventType = json_data.get_string("e")
        result.eventTime = json_data.get_int("E")
        result.pair = json_data.get_string("i")
        result.indexPrice = json_data.get_float("p")
        return result





class IndexPrice:

    def __init__(self):
        self.pair = ""
        self.indexPrice = 0.0
        self.time = 0
    
    @staticmethod
    def json_parse(json_data):
        result = IndexPrice()
        result.pair = json_data.get_string("pair")
        result.indexPrice = json_data.get_float("indexPrice")
        result.estimatedSettlePrice = json_data.get_float("estimatedSettlePrice")
        result.time = json_data.get_int("time")

        return result




class WebSocketDefine:
    # Uri = "wss://dstream.binance.com/ws"
    # testnet
    Uri = "wss://dstream.binancefuture.com/ws"
    # testnet new spec
    # Uri = "wss://sdstream.binancefuture.com/ws"

class RestApiDefine:
    # Url = "https://dapi.binance.com"
    # testnet
    Url = "https://testnet.binancefuture.com"







#!/usr/bin/env python3
from setuptools import setup

setup(
    name="tcb-binance",
    version="1.1.3",
    packages=['binance_f', 'binance_f.impl', 'binance_f.impl.utils', 'binance_f.exception', 'binance_f.model', 'binance_f.base', 'binance_f.constant', 'binance_d', 'binance_d.impl', 'binance_d.impl.utils', 'binance_d.exception', 'binance_d.model', 'binance_d.base', 'binance_d.constant'],
    install_requires=['requests', 'apscheduler', 'websocket-client', 'urllib3', 'tzlocal>3.0']
)




"""
return the taker/maker commission rate
"""

class CommissionRate:
    def __init__(self):
        self.symbol = ""
        self.makerCommissionRate = 0.0
        self.takerCommissionRate = 0.0

    @staticmethod
    def json_parse(json_data):
        result = CommissionRate()
        result.symbol = json_data.get_string("symbol")
        result.makerCommissionRate = json_data.get_float("makerCommissionRate")
        result.takerCommissionRate = json_data.get_float("takerCommissionRate")
        return result